==> open-xchange-mobile-api-facade_1.0.3.orig.tar.bz2: open-xchange-mobile-api-facade-1.0.3/com.openexchange.mobile.api.facade/src/com/openexchange/mobile/api/facade/models/Priority.java <==
/*
 *
 *    OPEN-XCHANGE legal information
 *
 *    All intellectual property rights in the Software are protected by
 *    international copyright laws.
 *
 *
 *    In some countries OX, OX Open-Xchange, open xchange and OXtender
 *    as well as the corresponding Logos OX Open-Xchange and OX are registered
 *    trademarks of the OX Software GmbH group of companies.
 *    The use of the Logos is not covered by the GNU General Public License.
 *    Instead, you are allowed to use these Logos according to the terms and
 *    conditions of the Creative Commons License, Version 2.5, Attribution,
 *    Non-commercial, ShareAlike, and the interpretation of the term
 *    Non-commercial applicable to the aforementioned license is published
 *    on the web site http://www.open-xchange.com/EN/legal/index.html.
 *
 *    Please make sure that third-party modules and libraries are used
 *    according to their respective licenses.
 *
 *    Any modifications to this package must retain all copyright notices
 *    of the original copyright holder(s) for the original code used.
 *
 *    After any such modifications, the original and derivative code shall remain
 *    under the copyright of the copyright holder(s) and/or original author(s)per
 *    the Attribution and Assignment Agreement that can be located at
 *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
 *    given Attribution for the derivative code and a license granting use.
 *
 *     Copyright (C) 2016-2020 OX Software GmbH
 *     Mail: info@open-xchange.com
 *
 *
 *     This program is free software; you can redistribute it and/or modify it
 *     under the terms of the GNU General Public License, Version 2 as published
 *     by the Free Software Foundation.
 *
 *     This program is distributed in the hope that it will be useful, but
 *     WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
 *     or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License
 *     for more details.
 *
 *     You should have received a copy of the GNU General Public License along
 *     with this program; if not, write to the Free Software Foundation, Inc., 59
 *     Temple Place, Suite 330, Boston, MA 02111-1307 USA
 *
 */

package com.openexchange.mobile.api.facade.models;

import java.util.HashMap;
import java.util.Map;

import lombok.Getter;

public enum Priority {

    NOPRIORITY(0, "noPriority"),
    VERYHIGH(1, "veryHigh"),
    HIGH(2, "high"),
    MEDIUM(3, "medium"),
    LOW(4, "low"),
    VERYLOW(5, "veryLow");

    private static class Cache {
        private static Map<Integer, Priority> store = new HashMap<>();
    }

    @Getter
    private int intValue;

    @Getter
    private String strValue;

    private Priority(int intValue, String strValue) {
        this.intValue = intValue;
        this.strValue = strValue;
        Cache.store.put(intValue, this);
    }

    public static Priority valueOf(int value) {
        Priority priority = Cache.store.get(value);
        if (priority == null) {
            throw new IllegalArgumentException("No enum constant matches value: " + value);
        }
        return priority;
    }

}

==> open-xchange-mobile-api-facade_1.0.6.orig.tar.bz2: open-xchange-mobile-api-facade-1.0.6/com.openexchange.mobile.api.facade/src/com/openexchange/mobile/api/facade/models/Priority.java <==
/*
 *
 *    OPEN-XCHANGE legal information
 *
 *    All intellectual property rights in the Software are protected by
 *    international copyright laws.
 *
 *
 *    In some countries OX, OX Open-Xchange, open xchange and OXtender
 *    as well as the corresponding Logos OX Open-Xchange and OX are registered
 *    trademarks of the OX Software GmbH group of companies.
 *    The use of the Logos is not covered by the GNU General Public License.
 *    Instead, you are allowed to use these Logos according to the terms and
 *    conditions of the Creative Commons License, Version 2.5, Attribution,
 *    Non-commercial, ShareAlike, and the interpretation of the term
 *    Non-commercial applicable to the aforementioned license is published
 *    on the web site http://www.open-xchange.com/EN/legal/index.html.
 *
 *    Please make sure that third-party modules and libraries are used
 *    according to their respective licenses.
 *
 *    Any modifications to this package must retain all copyright notices
 *    of the original copyright holder(s) for the original code used.
 *
 *    After any such modifications, the original and derivative code shall remain
 *    under the copyright of the copyright holder(s) and/or original author(s)per
 *    the Attribution and Assignment Agreement that can be located at
 *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
 *    given Attribution for the derivative code and a license granting use.
 *
 *     Copyright (C) 2016-2020 OX Software GmbH
 *     Mail: info@open-xchange.com
 *
 *
 *     This program is free software; you can redistribute it and/or modify it
 *     under the terms of the GNU General Public License, Version 2 as published
 *     by the Free Software Foundation.
 *
 *     This program is distributed in the hope that it will be useful, but
 *     WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
 *     or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License
 *     for more details.
 *
 *     You should have received a copy of the GNU General Public License along
 *     with this program; if not, write to the Free Software Foundation, Inc., 59
 *     Temple Place, Suite 330, Boston, MA 02111-1307 USA
 *
 */

package com.openexchange.mobile.api.facade.models;

import java.util.HashMap;
import java.util.Map;

import lombok.Getter;

public enum Priority {

    NOPRIORITY(0, "noPriority"),
    VERYHIGH(1, "veryHigh"),
    HIGH(2, "high"),
    MEDIUM(3, "medium"),
    LOW(4, "low"),
    VERYLOW(5, "veryLow");

    private static class Cache {
        private static Map<Integer, Priority> store = new HashMap<>();
    }

    @Getter
    private int intValue;

    @Getter
    private String strValue;

    Priority(int intValue, String strValue) {
        this.intValue = intValue;
        this.strValue = strValue;
        Cache.store.put(intValue, this);
    }

    public static Priority valueOf(int value) {
        Priority priority = Cache.store.get(value);
        if (priority == null) {
            throw new IllegalArgumentException("No enum constant matches value: " + value);
        }
        return priority;
    }

}
